rmdawn package — Rmdawn 0.0.1 documentation

# rmdawn package

## Submodules

## rmdawn.rmdawn module

`rmdawn.rmdawn.` `rmdawn`(filenames: List[str]) → str

  Create an R markdown file from markdown and code files.

## rmdawn.rmdusk module

`rmdawn.rmdusk.` `extract_after`(string, start)

`rmdawn.rmdusk.` `extract_between`(string, start, end)

`rmdawn.rmdusk.` `rmdusk`(filename: str) → str

  Extract YAML, code, and markdown files from an R markdown file.

## Module contents

Rmdawn: a Python package for (de)constructing R markdown files.